#include "fireLib.h"
#include "firelib.c"
#define INFINITY 999999999.     /* or close enough */

/* NOTE 1: Change these to modify map size & resolution. */
static int    Rows   = 20;     /* Number of rows in each map. */
static int    Cols   = 20;     /* Number of columns in each map. */
static double CellWd = 50.;    /* Cell width (E-W) in feet. */
static double CellHt = 50.;    /* Cell height (N-S) in feet. */

/* NOTE 2: Change these to set uniform burning conditions. */
static size_t Model   = 11;      /* NFFL 1 */
static double WindSpd = 15.;     /* mph */
static double WindDir = 115.;     /* degrees clockwise from north */
static double Slope   = 0.0;    /* fraction rise / reach */
static double Aspect  = 0.0;    /* degrees clockwise from north */
static double M1      = .10;    /* 1-hr dead fuel moisture */
static double M10     = .10;    /* 10-hr dead fuel moisture */
static double M100    = .10;    /* 100-hr dead fuel moisture */
static double Mherb   = 1.00;   /* Live herbaceous fuel moisture */
static double Mwood   = 1.50;   /* Live woody fuel moisture */

int main ()
{
    FuelCatalogPtr catalog;     /* fuel catalog handle */
    int    row, col, cell;      /* row, col, and index of current cell */
    int    n, cells;            /* neighbor index, total number of map cells */
    size_t modelNumber;         /* fuel model number at current cell */
    double nDist[8];            /* distance to each neighbor */
    double nAzm[8];             /* compass azimuth to each neighbor (0=N) */
    double moisture[6];         /* fuel moisture content at current cell */
    /* neighbor's address*/     /* N  NE   E  SE   S  SW   W  NW */
    static int nCol[8] =        {  0,  1,  1,  1,  0, -1, -1, -1};
    static int nRow[8] =        { -1, -1,  0,  1,  1,  1,  0, -1};

    FILE *fPtr;
    if ( (fPtr = fopen("Calculus.txt","w")) == NULL )
    {
	printf("Unable to open Calculus.txt \n");
	return (FIRE_STATUS_ERROR);
    }
    /* Calculate distance across cell to each neighbor and its azimuth. */
    for ( n=0; n<8; n++ )
    {
	nDist[n] = sqrt ( nCol[n] * CellWd * nCol[n] * CellWd
			+ nRow[n] * CellHt * nRow[n] * CellHt );
	nAzm[n] = n * 45.;
    }

    catalog = Fire_FuelCatalogCreateStandard("Standard", 13);
    Fire_FlameLengthTable(catalog, 500, 0.1);

    modelNumber = Model;
    moisture[0] = M1;
    moisture[1] = M10;
    moisture[2] = M100;
    moisture[3] = M100;
    moisture[4] = Mherb;
    moisture[5] = Mwood;

    Fire_SpreadNoWindNoSlope(catalog, modelNumber, moisture);

    Fire_SpreadWindSlopeMax(catalog, modelNumber, 88. * WindSpd, WindDir, Slope, Aspect);

    fprintf(fPtr,"Datos y valores obtenidos utilizando el modelo teorico de ROTHERMEL \n");
    fprintf(fPtr,"-----------------------------------------------------------\n");
    fprintf(fPtr,"Direccin del viento = %f (angulos en el sentido del reloj con respecto al norte)\n",WindDir);
    fprintf(fPtr,"Velocidad del viento = %f [kph]\n",WindSpd*1.609);
    fprintf(fPtr,"Modelo NFFL = %d \n",modelNumber);
    fprintf(fPtr,"Ancho de la celda = %f [m] (E-W)\n",CellWd*0.3048);
    fprintf(fPtr,"Alto de la celda  = %f [m] (N-S)\n",CellHt*0.3048);
    fprintf(fPtr,"Max. Spread = %f [mpm]( en direccion donde va el viento)\n\n", Fuel_SpreadMax(catalog,modelNumber)*0.3048);
    Fire_SpreadAtAzimuth(catalog, modelNumber, nAzm[0], FIRE_NONE);
    fprintf(fPtr,"0 Spread = %f [mpm]\n", Fuel_SpreadAny(catalog,modelNumber)*0.3048);
    fprintf(fPtr,"Distancia = %f [m]\n\n",nDist[0]*0.3048);
    Fire_SpreadAtAzimuth(catalog, modelNumber, nAzm[1], FIRE_NONE);
    fprintf(fPtr,"45 Spread = %f [mpm]\n", Fuel_SpreadAny(catalog,modelNumber)*0.3048);
    fprintf(fPtr,"Distancia = %f [m]\n\n",nDist[1]*0.3048);
    Fire_SpreadAtAzimuth(catalog, modelNumber, nAzm[2], FIRE_NONE);
    fprintf(fPtr,"90 Spread = %f [mpm]\n", Fuel_SpreadAny(catalog,modelNumber)*0.3048);
    fprintf(fPtr,"Distancia = %f [m]\n\n",nDist[2]*0.3048);
    Fire_SpreadAtAzimuth(catalog, modelNumber, nAzm[3], FIRE_NONE);
    fprintf(fPtr,"135 Spread = %f [mpm]\n", Fuel_SpreadAny(catalog,modelNumber)*0.3048);
    fprintf(fPtr,"Distancia = %f [m]\n\n",nDist[3]*0.3048);
    Fire_SpreadAtAzimuth(catalog, modelNumber, nAzm[4], FIRE_NONE);
    fprintf(fPtr,"180 Spread = %f [mpm]\n", Fuel_SpreadAny(catalog,modelNumber)*0.3048);
    fprintf(fPtr,"Distancia = %f [m]\n\n",nDist[4]*0.3048);
    Fire_SpreadAtAzimuth(catalog, modelNumber, nAzm[5], FIRE_NONE);
    fprintf(fPtr,"225 Spread = %f [mpm]\n", Fuel_SpreadAny(catalog,modelNumber)*0.3048);
    fprintf(fPtr,"Distancia = %f [m]\n\n",nDist[5]*0.3048);
    Fire_SpreadAtAzimuth(catalog, modelNumber, nAzm[6], FIRE_NONE);
    fprintf(fPtr,"270 Spread = %f [mpm]\n", Fuel_SpreadAny(catalog,modelNumber)*0.3048);
    fprintf(fPtr,"Distancia = %f [m]\n\n",nDist[6]*0.3048);
    Fire_SpreadAtAzimuth(catalog, modelNumber, nAzm[7], FIRE_NONE);
    fprintf(fPtr,"315 Spread = %f [mpm]\n", Fuel_SpreadAny(catalog,modelNumber)*0.3048);
    fprintf(fPtr,"Distancia = %f [m]\n\n",nDist[7]*0.3048);
    fclose(fPtr);
    return (0);
}